@@ -227,7 +227,7 @@ def openbis_definitions(entity):
             "identifier": "vocabularyId",
             "search": { "@type": "as.dto.vocabulary.search.VocabularySearchCriteria" },
             "create": { "@type": "as.dto.vocabulary.create.VocabularyCreation"}, 
-            "update": { "@type": "as.dto.vocabulary.upate.VocabularyUpdate"},
+            "update": { "@type": "as.dto.vocabulary.update.VocabularyUpdate"},
             "delete": { "@type": "as.dto.vocabulary.delete.VocabularyDeletionOptions"},
             "fetch":  { "@type": "as.dto.vocabulary.fetchoptions.VocabularyFetchOptions"},
         },
@@ -238,7 +238,7 @@ def openbis_definitions(entity):
             "multi": "".split(),
             "identifier": "vocabularyTermId",
             "create": { "@type": "as.dto.vocabulary.create.VocabularyTermCreation"},
-            "update": { "@type": "as.dto.vocabulary.upate.VocabularyTermUpdate"},
+            "update": { "@type": "as.dto.vocabulary.update.VocabularyTermUpdate"},
             "delete": { "@type": "as.dto.vocabulary.delete.VocabularyTermDeletionOptions"},
             "fetch":  { "@type": "as.dto.vocabulary.fetchoptions.VocabularyTermFetchOptions"},
         },
